@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20230131';
+our $VERSION = '0.20230331';
 
-# Table last modified: 2023-01-31
+# Table last modified: 2023-03-31
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[0-2]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -103,19 +103,19 @@ our %ZIP_TABLE = (
     '097' => '(?:8(?:5(?:10|85|5[58]|2[57])|6(?:[03]9|[68]6)))',
     '098' => '(?:(?:5(?:[78]92|298|595)|(?:28|62|0[13])92|1(?:69[23]|792)|339[23568]))',
     '099' => '(?:(?:2(?:19[2-8]|49[235]|392)|1(?:49[2568]|19[78]|595)|3(?:29[23]|69[78])|4(?:19[256]|492)|(?:56|65)92|049[245]))',
-    '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|6[0-2457-9]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9])|1(?:7[2468]|1[0137-9]|8[124-9]|2[013-8]|0[1-57-9]|6[05689]|4[0-24]|5[0-24589]|3[0-69])|2(?:28|51|70|0[1357]|8[2358]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|2[1245]|3[1-38]|0[2367]|4[15]|1[01]|8[038])|5(?:11|33|4[03]|5[058]|6[07]|8[58]|7[57]|2[0-2]|0[235-7])|6(?:55|2[019]|3[19]|6[356]|7[67]|1[07]|0[126]|4[049])|4(?:02|5[06]|1[015]|3[09]|2[147]|[48][48])|0(?:19|5[015]|7[07-9]|8[068]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
-    '101' => '(?:8(?:5(?:7[5-9]|6[0-2568]|8[0135689]|1[0257-9]|4[2-58]|0[1246-9]|5[24589]|2[0-8]|3[0-5])|4(?:7[05-7]|0[57-9]|8[0135]|3[0379]|2[1-579]|5[0-4689]|4[13-9]|6[0-24-9]|1[0-25689])|3(?:6[2356]|0[12578]|7[0-258]|8[1358]|1[013-8]|5[0-689]|4[35-7]|2[13-9]|3[013568])|6(?:4[1-35-8]|8[28]|6[2578]|1[0-25-79]|3[01346-8]|5[14-6]|2[014-9]|7[026]|0[3-79])|9(?:01|50|7[0-37]|4[16]|8[36])|0(?:11|77|5[04]|0[128])|2(?:28|0[124]|1[0359])|7(?:0[137]|1[0-25-8])|1(?:01|89)))',
-    '102' => '(?:8(?:1(?:2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|7[0-25-8]|9[0-5]|4[0-24]|6[016]|1[0-257-9])|5(?:0[2-468]|1[0-2569]|8[0568]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|6[013-79])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|2[0146]|8[489]|3[037]|1[01479])|2(?:5[015]|7[2357]|3[0-24-68]|6[045]|8[28]|2[1-68]|[01][15]|4[016])|3(?:4[19]|7[0-37]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|5[0367]|0[1359])|0(?:30|77|8[0-358]|2[256]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
-    '103' => '(?:8(?:4(?:7[0-3]|2[2-7]|0[1-57]|6[0-24-68]|4[38]|3[0-589]|1[0-79]|8[024578]|5[016])|2(?:5[0-2569]|3\d|7[0368]|6[01356]|0[1-68]|8[2457]|1[0-248]|2[124589]|4[013578])|3(?:70|0[1378]|8[0348]|4[15-7]|1[1-478]|5[0-248]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|7[67]|6[068]|8[0469]|3[1269])|0[01]1))',
-    '104' => '(?:(?:8(?:1(?:2[2-589]|5[018]|6[12578]|1[014-8]|4[25]|8[389]|7[014-689]|3[0-589]|0[124589])|3(?:65|1[023579]|7[07-9]|2[458]|8[013689]|5[0167]|3[02358]|4[0-5]|0[12467])|5(?:72|1[028]|3[035689]|8[01458]|2[136-8]|5[014-689]|6[068]|4[35-8]|0[1256])|4(?:70|3[013589]|5[056]|1[3569]|0[124-8]|8[168]|2[0-469]|6[08]|4[02-49])|2(?:38|40|71|6[26]|5[0-24578]|1[0-258]|0[568]|8[0-59])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|0[1-47]|1[01]))|6241))',
-    '105' => '(?:(?:8(?:5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|4(?:7[0-257]|8[2-6]|5[1-36-8]|3[13-7]|6[014-689]|4[014-9]|2[0347-9]|1[0-24-9]|0[1-378])|6(?:7[026-8]|3[04]|6[0568]|8[015689]|2[0135-7]|5[468]|1[013-57]|4[0-24]|0[3468])|3(?:3[01358]|0[1-8]|2[0235]|1[0-589])|0(?:[12]0|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[1267]))|7(?:0(?:[58]0|77)|444)|6[09]50))',
+    '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|6[0-2457-9]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9])|1(?:7[2468]|1[0137-9]|8[124-9]|2[013-8]|0[1-57-9]|6[05689]|4[0-24]|5[0-24589]|3[0-69])|2(?:28|51|70|0[1357]|8[2358]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|2[1245]|0[2367]|4[15]|1[01]|3[1-358]|8[038])|5(?:11|33|4[03]|5[058]|6[07]|8[58]|7[57]|2[0-2]|0[235-7])|6(?:55|2[019]|3[19]|6[356]|7[67]|1[07]|0[126]|4[049])|4(?:02|5[06]|1[015]|3[09]|2[147]|[48][48])|0(?:19|5[015]|7[07-9]|8[068]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
+    '101' => '(?:8(?:5(?:7[5-9]|6[0-2568]|8[0135689]|1[0257-9]|4[2-58]|0[1246-9]|5[24589]|2[0-8]|3[0-5])|4(?:7[05-7]|0[57-9]|8[0135]|3[0379]|2[1-579]|5[0-4689]|4[13-9]|6[0-24-9]|1[0-25689])|3(?:6[2356]|0[12578]|7[0-258]|8[1358]|1[013-8]|5[0-689]|3[13568]|4[35-7]|2[13-9])|6(?:4[1-35-8]|8[28]|6[2578]|1[0-25-79]|3[01346-8]|5[14-6]|2[014-9]|7[026]|0[3-79])|9(?:01|50|7[0-37]|4[16]|8[36])|0(?:11|77|5[04]|0[128])|2(?:28|0[124]|1[0359])|7(?:0[137]|1[0-25-8])|1(?:01|89)))',
+    '102' => '(?:8(?:1(?:2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|7[0-25-8]|9[0-5]|4[0-24]|6[016]|1[0-257-9])|5(?:0[2-468]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|1[0-3569]|6[013-79]|8[023568])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|2[0146]|8[489]|3[037]|1[01479])|2(?:5[015]|7[2357]|3[0-24-68]|6[045]|8[28]|2[1-68]|[01][15]|4[016])|3(?:7[0-37]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|4[139]|5[0367]|0[1359])|0(?:30|77|8[0-358]|2[256]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
+    '103' => '(?:8(?:4(?:7[0-3]|2[2-7]|0[1-57]|6[0-24-68]|4[38]|3[0-589]|1[0-79]|8[024578]|5[016])|2(?:5[0-2569]|3\d|6[01356]|7[036-8]|0[1-68]|8[2457]|1[0-248]|2[124589]|4[013578])|3(?:70|0[1378]|8[0348]|4[15-7]|1[1-478]|5[0-248]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|3[169]|7[67]|6[068]|8[0469])|0[01]1))',
+    '104' => '(?:(?:8(?:1(?:2[2-589]|5[018]|6[12578]|4[25]|8[389]|7[014-689]|3[0-589]|1[0-24-8]|0[124589])|3(?:1[023579]|7[07-9]|2[458]|8[013689]|6[35]|5[0167]|3[02358]|4[0-5]|0[12467])|4(?:70|3[013589]|5[056]|1[3569]|0[124-8]|8[168]|2[0-469]|6[08]|4[02-49])|5(?:72|1[028]|8[01458]|2[136-8]|5[014-689]|6[068]|3[03689]|4[35-8]|0[1256])|2(?:38|40|71|6[26]|5[0-24578]|1[0-258]|0[568]|8[0-59])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|0[1-47]|1[01]))|6241))',
+    '105' => '(?:(?:8(?:5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|4(?:7[0-257]|8[2-6]|5[1-36-8]|3[13-7]|6[014-689]|4[014-9]|2[0347-9]|1[0-24-9]|0[1-378])|6(?:7[026-8]|3[04]|6[0568]|8[015689]|2[0135-7]|5[468]|1[013-57]|4[0-24]|0[3468])|3(?:3[01358]|0[1-8]|2[0235]|1[0-589])|0(?:10|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[1267]))|7(?:0(?:[58]0|77)|444)|6[09]50))',
     '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|3[17]|1[458]|7[135-8]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[168]|6[58]|3[0569]|0[18]|2[0256])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
-    '107' => '(?:8(?:4(?:20|34|5[06]|0[1-4]|7[17]|8[24]|6[036-8]|1[0-246-9]|4[08])|5(?:[37]2|81|1[14]|0[2578]|2[0178]|6[037]|5[0268]|4[56])|6(?:01|50|8[06]|1[5-79]|7[46]|3[0-3689]|2[0357]|6[68])|3(?:60|4[0289]|7[013]|2[0346]|8[048]|3[026]|5[125])|0(?:[16]0|77|0[16])|797))',
-    '108' => '(?:(?:8(?:5(?:2[0-35]|4[0358]|3[02369]|6[0468]|7[0135]|5[0-35-8]|1[0-2]|0[1-46-9]|8[0-3568])|3(?:2[25689]|7[2359]|8[013-689]|3[0348]|5[058]|6[01]|4[15]|1[035]|0[13578])|2(?:8[028]|2[0-245]|7[056]|4[0-38]|1[0-25-7]|0[1-36-9]|3[0-4]|5[05])|4(?:56|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|1[0-25-7]|2[28]|3[1-3689]|0[267]|4[0-28])|0(?:[258]0|[17]1|0[15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
+    '107' => '(?:8(?:4(?:20|34|5[06]|0[1-4]|7[17]|8[24]|6[036-8]|1[0-246-9]|4[08])|5(?:[37]2|81|1[14]|0[2578]|2[0178]|6[037]|5[0268]|4[56])|6(?:01|50|66|1[5-79]|7[46]|3[0-3689]|8[068]|2[0357])|3(?:60|4[0289]|7[013]|2[0346]|8[048]|3[026]|5[125])|0(?:[16]0|77|0[16])|797))',
+    '108' => '(?:(?:8(?:5(?:2[0-35]|4[0358]|3[02369]|6[0468]|1[0-25]|7[0135]|5[0-35-8]|0[1-46-9]|8[0-3568])|3(?:2[25689]|7[2359]|8[013-689]|3[0348]|5[058]|6[01]|4[15]|1[035]|0[13578])|2(?:8[028]|2[0-245]|7[056]|4[0-38]|1[0-25-7]|0[1-36-9]|3[0-4]|5[05])|4(?:56|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|1[0-25-7]|2[28]|3[1-3689]|0[267]|4[0-28])|0(?:[258]0|[17]1|0[15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|4[01368]|7[5-8]|3[0-4679]|0[1-3579]|1[0135-7]|5[059]|8[02-468]|2[024])|6(?:53|2[0-2568]|6[0259]|4[1245]|3[0158]|0[259]|8[015-7]|1[04589]|7[35-8])|7(?:8[027]|1[2-6]|2[235]|3[36]|0[68])|408|807))',
     '111' => '(?:8(?:5(?:43|1[0-258]|8[058]|5[1568]|7[57]|6[0167]|2[125]|0[125-8]|3[0-59])|6(?:4[028]|3[01379]|[12][0-258]|7[6-8]|8[1368]|0[2568]|6[16]|5[05])|7(?:[56]5|21|98|0[178]|1[01])|081))',
-    '112' => '(?:8(?:6(?:90|6[02-48]|4[245]|0[1467]|2[02579]|1[0-289]|7[01578]|5[0-57]|8[0-578]|3[02-5])|5(?:7[0356]|4[018]|6[02369]|2[458]|1[1246]|3[0138]|0[1-35689]|5[015-8]|8[035])|7(?:[156]0|78|0[12])|0(?:[01]1|88)|138))',
+    '112' => '(?:8(?:6(?:90|6[02-48]|4[245]|0[1467]|2[02579]|1[0-289]|7[01578]|5[0-57]|8[0-578]|3[0-5])|5(?:[78][0356]|4[018]|2[458]|6[2369]|1[1246]|3[0138]|0[1-35689]|5[015-8])|7(?:[156]0|78|0[12])|0(?:[01]1|88)|138))',
     '113' => '(?:8(?:4(?:4[148]|7[1479]|8[3-58]|2[0-3]|1[0-358]|6[2-6]|3[13-5]|5[0169]|0[1248])|5(?:70|0[13-579]|3[04-68]|6[0-46]|4[1369]|1[02379]|2[0145]|5[1356])|6(?:77|3[38]|5[04-8]|0[1-468]|8[16]|1[0-2]|6[0-378])|7(?:01|1[0-29])|139|311))',
     '114' => '(?:8(?:5(?:95|0[1-35-8]|8[013-58]|6[0-25]|2[0-468]|7[147]|4[01356]|5[02-57]|3[0-24589]|1[02457-9])|6(?:11|86|0[2-6])))',
     '115' => '(?:8(?:5(?:55|8[568]|1[01]|2[49])|(?:00|71)1|6(?:22|50)))',
@@ -125,7 +125,7 @@ our %ZIP_TABLE = (
     '123' => '(?:85(?:[58]8|40|1[1247]|0[135-9]))',
     '124' => '(?:85(?:60|77|2[04]|3[03589]|0[1-39]|8[58]|5[05]|1[01]))',
     '125' => '(?:8(?:5(?:0[3-8]|8[58]|1[1-47]|2[026])|601))',
-    '130' => '(?:8(?:5(?:8[03-58]|2[0-258]|7[057]|3[013-589]|5[3-8]|4[3568]|6[135-7]|0[13-9]|1[0-8])|6(?:25|86|7[17]|3[67]|5[05]|6[068]|1[125]|0[1-689]|4[024])|7(?:[12]0|0[16])))',
+    '130' => '(?:8(?:5(?:8[03-58]|2[0-258]|7[057]|3[013-589]|5[3-8]|4[3568]|6[135-7]|0[13-9]|1[0-8])|6(?:25|86|7[17]|3[367]|5[05]|6[068]|1[125]|0[1-689]|4[024])|7(?:[12]0|0[16])))',
     '131' => '(?:8(?:5(?:65|1[0-389]|3[03]|2[0467]|8[458]|5[05]|0[1357-9])|139|634|711))',
     '132' => '(?:8(?:5(?:[18]5|33|5[015]|0[137]|6[27])|6(?:01|74|[68][68])|7(?:11|3[029])))',
     '133' => '(?:8(?:5(?:[01]1|8[05]|5[238])|70[46]))',
@@ -151,7 +151,7 @@ our %ZIP_TABLE = (
     '158' => '(?:8(?:5(?:3[1349]|5[0-278]|8[0568]|1[0-48]|6[167]|4[349]|2[0235]|7[578]|0[1-3589])|6(?:40|66|3[0-3]|2[28]|1[05]|0[12])|7[07]1))',
     '160' => '(?:8(?:3(?:89|7[3-58]|3[01468]|0[14689]|[24][17]|1[169]|6[168]|5[1-38])|4(?:50|72|1[015]|3[03]|2[0239]|6[136]|4[147]|8[4-9]|0[1-37-9])|5(?:65|1[0-2569]|4[37]|0[17]|8[0-37-9]|2[0-249]|3[05]|7[157])|0(?:[01]1|70)|6(?:01|80)|8(?:01|12)|910))',
     '161' => '(?:8(?:5(?:08|11|75|3[19]|6[057]|5[236-8]|4[0156]|2[0-28])|710))',
-    '162' => '(?:8(?:6(?:[78]0|1[24-6]|2[0468]|5[04-6]|[36][689]|4[046]|0[1248])|4(?:33|5[015]|6[04]|4[0568]|7[1368]|0[27]|2[12]|8[48]|1[125])|5(?:75|4[03]|[16][25]|0[235]|3[05]|8[57]|5[16-8])|8(?:30|5[03]|0[1-8]|6[01])|0(?:55|60|2[0-2]|0[15])|7(?:0[17]|1[016-8])|953))',
+    '162' => '(?:8(?:6(?:[78]0|1[24-6]|2[0468]|5[04-6]|[36][689]|4[046]|0[1248])|4(?:33|5[015]|6[04]|4[0568]|7[1368]|8[048]|0[27]|2[12]|1[125])|5(?:75|4[03]|[16][25]|0[235]|3[05]|8[57]|5[16-8])|8(?:30|5[03]|0[1-8]|6[01])|0(?:55|60|2[0-2]|0[15])|7(?:0[17]|1[016-8])|953))',
     '163' => '(?:(?:0(?:5(?:5[378]|7[056]|6[0269])|6(?:7[5-7]|5[59]|6[359])|8(?:50|67|3[136])|2(?:78|87|6[18])|9(?:43|3[68])|4(?:56|78)|7[27]7)|1(?:3(?:50|63|71|4[59]|8[28])|0(?:7[13]|6[156]|5[35])|4(?:55|70|88)|5(?:88|3[37]))|8(?:6(?:02|26|80|3[89]|7[17]|6[016])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48))))',
     '164' => '(?:8(?:6(?:[25]0|66|8[26]|7[78]|1[167]|4[24]|[03][18])|5(?:[37]0|12|67|4[015]|2[25]|8[58]|5[05]|0[13-5])|7(?:25|0[15])))',
     '165' => '(?:8(?:(?:63|78)0|555))',
@@ -162,7 +162,7 @@ our %ZIP_TABLE = (
     '170' => '(?:(?:8(?:4(?:1[015-79]|2[013467]|0[124-69]|7[067]|4[0-248]|5[015-9]|6[0256]|8[08]|3[02-468])|6(?:[68]6|55|0[25]|3[35])|0(?:55|73)|5(?:51|85))|6080))',
     '171' => '(?:8(?:5(?:5[23578]|3[19]|7[027]|4[045]|2[0-35-7]|1[0-2468]|6[0189]|0[1-3578]|8[0268])|422))',
     '173' => '(?:8(?:5(?:[06]1|[23]0|4[03]|1[0-25-9]|8[058]|5[258])|6(?:48|3[29]|1[01]|0[1256])|710))',
-    '174' => '(?:8(?:5(?:[13]0|0[135]|6[027]|5[058]|2[014-6]|8[08])|6(?:12|46|51|3[0369]|8[068]|0[12])|7(?:[01]1|3[079]|4[0134])|860|903))',
+    '174' => '(?:8(?:5(?:[13]0|0[135]|6[027]|5[058]|2[014-6]|8[08])|6(?:12|46|51|3[0369]|8[068]|0[12])|7(?:[01]1|87|3[079]|4[0134])|860|903))',
     '175' => '(?:85(?:71|88))',
     '176' => '(?:85(?:[46]0|85|2[12568]|3[013-6]|0[1-37-9]|1[125-8]))',
     '177' => '(?:85(?:21|0[1-389]))',
@@ -197,7 +197,7 @@ our %ZIP_TABLE = (
     '208' => '(?:85(?:[58]5|0[1-3]))',
     '210' => '(?:(?:8(?:5(?:0[246]|6[0259]|2[13]|8[356]|3[178]|4[013-578]|7[067]|1[12]|5[127-9])|6(?:66|0[24]|8[016])|79[3-8])|9(?:5(?:11|26|55|67|82|3[03]|0[17])|650)))',
     '211' => '(?:8(?:5(?:40|66|3[03]|2[02]|7[07]|8[58]|5[05]|1[01]|0[125])|6(?:01|66|75|1[19])))',
-    '212' => '(?:8(?:5(?:30|6[0467]|2[05]|5[147]|7[0267]|8[1-5]|0[2589]|1[01])|60[23]))',
+    '212' => '(?:8(?:5(?:30|6[0467]|2[05]|5[147]|7[0267]|8[1-5]|0[2589]|1[01])|60[2-4]))',
     '213' => '(?:85(?:66|0[2357]|2[0-25]|1[125-7]|3[35]|7[0367]|5[0138]|8[06-9]))',
     '214' => '(?:85(?:[26]5|8[058]|7[01]))',
     '215' => '(?:85(?:09|30|42|66|7[06]|1[015]|8[58]|5[08]|2[017]))',
@@ -211,7 +211,7 @@ our %ZIP_TABLE = (
     '226' => '(?:85(?:[25]5|70|1[02]|0[1-37]))',
     '227' => '(?:85(?:22|40|0[1258]|1[28]))',
     '230' => '(?:8(?:5(?:11|7[17]|0[14]|5[05])|6(?:[68]6|11|28)|765))',
-    '231' => '(?:8(?:5(?:04|6[26]|3[469]|8[58]|5[05]|2[08]|4[49])|3(?:07|2[01348]|3[0158]|4[036]|1[0-6])|6(?:16|23|31|60|5[124]|8[29])|4(?:[368]4|45|7[78]|1[19])|7(?:7[12]|1[15])|00[18]|831|966))',
+    '231' => '(?:8(?:5(?:04|6[26]|8[58]|3[0469]|2[08]|4[49]|5[035])|3(?:07|2[01348]|3[0158]|4[036]|1[0-6])|6(?:16|23|31|60|5[124]|8[29])|4(?:[368]4|45|7[78]|1[19])|7(?:7[12]|1[15])|00[18]|831|966))',
     '232' => '(?:8(?:5(?:31|8[057]|5[58]|1[05])|6(?:02|88)))',
     '233' => '(?:85(?:0[1-3]|5[056]))',
     '235' => '(?:85(?:58|2[23]|0[15]))',
@@ -227,19 +227,19 @@ our %ZIP_TABLE = (
     '245' => '(?:8(?:5(?:[16]0|42|89|5[058]|7[57])|65[01]))',
     '246' => '(?:85(?:20|5[06]))',
     '247' => '(?:8(?:5(?:[156]0|8[58]|7[078]|3[038])|6(?:[13]0|86)|730))',
-    '248' => '(?:8(?:55[58]|686))',
+    '248' => '(?:8(?:555|686))',
     '249' => '(?:8(?:510|686))',
     '250' => '(?:(?:0(?:2(?:80|9[2-68])|19[23]|39[28]|493|592)|85(?:11|55|60|88)))',
     '251' => '(?:8(?:5(?:22|70|4[03]|8[018]|5[0158]|3[0134]|1[0135]|6[067]|0[125])|601))',
-    '252' => '(?:(?:5(?:2(?:01|33|77|9[3-578]|8[0568]|2[0-25]|6[09]|1[0-5]|5[0258])|1(?:[56]2|8[13589]|7[27]|9[12]))|0(?:3(?:7[013-578]|9[258]|8[013568])|88[0-3568])|85(?:[02]2|11|40|85|3[89]|7[02]|6[067]|5[08])|119[235]))',
+    '252' => '(?:(?:5(?:2(?:01|33|77|9[3-578]|8[05-8]|2[0-25]|6[09]|1[0-5]|5[0258])|1(?:[56]2|8[13589]|7[27]|9[12]))|0(?:3(?:7[013-578]|9[258]|8[013568])|88[0-3568])|85(?:[02]2|11|40|85|3[89]|7[02]|6[067]|5[08])|119[235]))',
     '253' => '(?:(?:8(?:5(?:10|22|43|7[17]|8[58]|5[05]|3[01])|6(?:60|86))|019[356]))',
     '254' => '(?:8(?:5(?:10|43|55|78|0[1-3]|6[27]|3[023]|8[589])|6(?:01|86|1[024])))',
     '255' => '(?:8555)',
     '256' => '(?:8510)',
     '257' => '(?:85(?:[23]3|11|55|66|77|8[458]|0[12]))',
     '258' => '(?:(?:85(?:11|77|85|3[38]|0[16])|0195))',
-    '259' => '(?:(?:0(?:1(?:9[2-46-8]|8[01])|39[2356])|1(?:1(?:8[5-8]|9[236-8])|[23]92)))',
-    '260' => '(?:8(?:6(?:0[13467]|1[0-389]|2[0-24-79]|5[46]|4[2578]|6[0-35-8]|7[0-357]|8[258]|3[135-7])|5(?:40|7[0257]|5[1257-9]|8[0568]|0[1-35-9]|3[4-68]|6[0-467]|2[13478]|1[0-3568])|7(?:1[02357]|0[137]|2[02]|3[034])))',
+    '259' => '(?:(?:0(?:1(?:9[2-467]|8[01])|39[2356])|1(?:1(?:8[5-8]|9[236-8])|[23]92)))',
+    '260' => '(?:8(?:6(?:0[13467]|1[0-389]|2[0-24-79]|5[46]|4[2578]|6[0-35-8]|7[0-357]|8[258]|3[135-7])|5(?:40|7[0257]|5[1257-9]|8[0568]|0[1-35-9]|3[4-68]|6[0-467]|2[13478]|1[0-3568])|7(?:1[02357]|0[137]|3[34]|2[02])))',
     '261' => '(?:8(?:5(?:1[0-35]|3[0359]|6[068]|7[57]|5[0248]|0[1-478]|2[0-2]|8[125-8]|4[145])|6(?:09|86)|733))',
     '262' => '(?:8(?:5(?:0[26]|1[0-24])|733))',
     '263' => '(?:8(?:5(?:[12]2|33|66|77|8[58]|5[05]|0[56])|733))',
@@ -247,8 +247,8 @@ our %ZIP_TABLE = (
     '265' => '(?:8501)',
     '266' => '(?:8(?:550|733))',
     '270' => '(?:(?:1(?:3(?:8[0-3579]|9[23568])|19[2468]|49[2356]|69[3-5]|592)|2(?:2(?:8[08]|9[25-8])|39[23])|01(?:89|9[24-8])|85(?:[0-2]1|55)))',
-    '271' => '(?:8(?:5(?:01|22|3[03]|8[058]|1[0158]|5[0157]|6[02-4])|6(?:66|72|2[05])))',
-    '272' => '(?:(?:85(?:01|73|4[03]|3[38]|5[058]|2[02]|8[0158]|1[0-468]|6[01])|019[35]))',
+    '271' => '(?:8(?:5(?:01|22|3[03]|[18][058]|5[157]|6[02-4])|6(?:66|72|2[05])))',
+    '272' => '(?:(?:85(?:01|73|4[03]|3[38]|5[058]|2[02]|8[0158]|1[0-468]|6[01])|01(?:88|9[35])))',
     '273' => '(?:(?:8(?:5(?:3[03]|2[0-3]|8[458]|1[0-25]|7[048]|6[067]|4[023]|5[01568]|0[1-68])|6(?:01|10|27)|7(?:10|33))|019[2357]))',
     '274' => '(?:8(?:5(?:[12]0|77|85|3[03]|0[13-7]|5[58])|601))',
     '275' => '(?:8(?:5(?:02|11|33|[28][058]|6[05]|7[25-7]|5[01])|6(?:[01]1|66)))',
@@ -264,7 +264,7 @@ our %ZIP_TABLE = (
     '287' => '(?:(?:8(?:5(?:[58]5|10|0[1-3])|601)|0292))',
     '288' => '(?:8601)',
     '289' => '(?:(?:1(?:59[2-4]|[138]92|29[78]|69[23]|793)|0(?:[124-6]92|39[23])|2(?:19[278]|292|595)))',
-    '290' => '(?:(?:8(?:5(?:40|77|6[06]|0[13]|8[058]|5[0158]|[13][01])|610)|019[2-4]))',
+    '290' => '(?:(?:8(?:5(?:40|77|0[13]|8[058]|5[0158]|6[067]|[13][01])|610)|019[2-4]))',
     '292' => '(?:8(?:5(?:01|2[025]|3[0359]|6[58]|5[05]|1[01])|6(?:11|86)))',
     '293' => '(?:85(?:06|11))',
     '294' => '(?:8(?:50[1-3]|[67]01))',
@@ -291,7 +291,7 @@ our %ZIP_TABLE = (
     '315' => '(?:(?:8(?:5(?:85|2[257]|1[1-368])|640)|0195))',
     '316' => '(?:85(?:11|33|0[12]))',
     '317' => '(?:8(?:5(?:[58]5|11)|60[12]))',
-    '318' => '(?:85[01]1)',
+    '318' => '(?:85(?:11|0[15]))',
     '319' => '(?:(?:1(?:1(?:8[248]|9[24-7])|29[235]|59[23]|393)|0(?:39[3-57]|29[245]|19[28])|2[16]92|3595))',
     '320' => '(?:8(?:5(?:5[015]|3[0-38]|0[1-35-8]|8[058]|4[013]|7[07]|6[046]|2[1-358]|1[0-2457])|6(?:01|20|55|68|1[018]|8[068])))',
     '321' => '(?:(?:3(?:29[235-8]|39[2358]|49[378]|59[578])|0(?:29[2358]|19[458]|59[235]|692)|2(?:59[23568]|49[23]|792)|4(?:39[23568]|29[235])|1(?:29[238]|49[23])|85(?:[58]5|0[25])))',
@@ -303,7 +303,7 @@ our %ZIP_TABLE = (
     '327' => '(?:(?:8(?:5(?:11|33|55|0[13])|6(?:78|0[13]))|0(?:59[25]|192|398)))',
     '328' => '(?:(?:8(?:5(?:33|0[1-4]|5[0568]|8[5-8])|6(?:86|6[68]))|0192))',
     '329' => '(?:(?:0(?:49[238]|59[568]|69[26]|195)|1(?:19[3468]|39[235]|292|493)|2(?:79[23]|99[23]|[12]92)|4(?:49[238]|392)|3292))',
-    '330' => '(?:(?:9(?:5(?:90|5[013589]|4[03-58]|8[0-36-8]|6[4-6]|3[156]|2[05]|7[57]|1[12]|0[1-37-9])|6(?:[69]6|11|30|88|0[18]|2[126])|7(?:3[19]|2[07]|9[2367]|1[0357])|3(?:30|77|0[13]|1[01])|0(?:11|45)|1(?:09|11)|850)|8(?:5(?:6[24-6]|4[78]|5[0-37]|0[13568]|3[238]|1[0189]|2[29]|7[129]|8[0159])|6(?:34|47|69|71|0[13]|8[68])|7(?:08|10|77))))',
+    '330' => '(?:(?:9(?:5(?:90|5[013589]|4[03-58]|8[0-36-8]|6[4-6]|3[156]|2[05]|7[57]|1[12]|0[1-37-9])|7(?:9[1-367]|3[19]|2[07]|1[0357])|6(?:[69]6|11|30|88|0[18]|2[126])|3(?:30|77|0[13]|1[01])|0(?:11|45)|1(?:09|11)|850)|8(?:5(?:6[24-6]|4[78]|5[0-37]|0[13568]|3[238]|1[0189]|2[29]|7[129]|8[0159])|6(?:34|47|69|71|0[13]|8[68])|7(?:08|10|77))))',
     '331' => '(?:(?:8(?:5(?:[24]0|01|77|1[13]|8[05-8]|5[02]|6[07]|3[237])|6(?:25|33|58|8[6-8])|701)|95(?:[1-35]0|77)))',
     '332' => '(?:8(?:5(?:21|48|77|85|0[1-3]|5[568]|1[12])|6(?:[68]6|01|54)))',
     '333' => '(?:86[01]1)',
@@ -346,7 +346,7 @@ our %ZIP_TABLE = (
     '370' => '(?:(?:8(?:5(?:[01]1|[68]5|22|43|3[17]|5[05])|6(?:[01]1|22|86|6[68]))|1(?:39[2-6]|19[2356]|29[23]|592)|0(?:59[568]|49[25]|193|692|795)|2(?:39[23568]|49[58]|[12]92)|3(?:59[2-4]|[146]92|39[23])))',
     '371' => '(?:(?:8(?:5(?:[58][05-7]|0[1-578]|1[0-7]|2[0-2578]|4[38]|3[01359]|7[023]|6[017])|6(?:[36]6|01|40|77|1[167]|2[05]|8[68]))|0(?:29[2-4]|192)))',
     '372' => '(?:8(?:5(?:10|58|67|8[058]|0[128])|686))',
-    '373' => '(?:8(?:5(?:21|78|1[0-35]|0[1589]|8[58]|5[0157]|3[01]|6[017])|6(?:01|22|6[068]|8[68]|1[01])|718))',
+    '373' => '(?:8(?:5(?:21|78|1[0-35]|0[1589]|8[58]|5[0157]|3[01]|6[017])|6(?:01|22|[68][068]|1[01])|718))',
     '374' => '(?:(?:8(?:5(?:01|20|33|55|77|88|1[0-28])|6(?:11|22|40|86|0[18]))|019[23]))',
     '375' => '(?:8(?:50[1-6]|60[1-4]))',
     '376' => '(?:(?:8(?:5(?:31|85|1[056]|2[38]|5[58]|0[12])|6(?:86|6[68]))|0(?:19[2-4]|39[27])))',
@@ -373,7 +373,7 @@ our %ZIP_TABLE = (
     '397' => '(?:(?:8(?:5(?:67|71|8[58]|5[05])|60[29])|0[23]92))',
     '398' => '(?:8(?:6(?:86|0[12])|501))',
     '399' => '(?:(?:8(?:7(?:44|60|0[127]|2[0-258]|5[0145]|1[0-2]|3[0389])|2(?:9[2357]|8[1-3568])|3(?:86|92)|69[56]|192)|4(?:5(?:7[0-35-8]|6[4-8]|8[13-9]|9[2-578])|69[235-7]|39[2-5]|19[25]|498)|0(?:7(?:9[67]|8[1256])|49[235-8]|29[235])|3(?:19[23]|295|797|892)|1(?:392|511|689|895)|9(?:192|393|494)|719[24]|6493))',
-    '400' => '(?:(?:8(?:5(?:2[015]|8[568]|1[0-25]|4[03-5]|7[01578]|5[025689]|0[125689]|6[56]|3[1356])|6(?:01|10|33|66)|794)|0(?:2(?:80|9[238])|19[2-6]|49[2358]|39[358]|59[238]|69[235])|159[2-478]))',
+    '400' => '(?:(?:8(?:5(?:2[015]|8[568]|1[0-25]|4[03-5]|7[01578]|5[025689]|0[125689]|6[56]|3[1356])|6(?:01|10|33|6[06])|794)|0(?:2(?:80|9[238])|19[2-6]|49[2358]|39[358]|59[238]|69[235])|159[2-478]))',
     '401' => '(?:(?:0(?:3(?:80|9[5-8])|59[257]|292)|8[56]01))',
     '402' => '(?:85(?:01|55|80))',
     '403' => '(?:8(?:5(?:22|55)|601))',
@@ -413,7 +413,7 @@ our %ZIP_TABLE = (
     '439' => '(?:865[01])',
     '440' => '(?:8(?:5(?:43|0[124-8]|3[013]|[12][0-8])|60[134]))',
     '441' => '(?:(?:8(?:5(?:6[06]|2[025]|5[058]|7[07]|4[05]|8[08]|0[1-37]|1[0-2579]|3[039])|6[68]6)|0(?:19[3-5]|29[25]|39[23])|3(?:19[2-6]|492|695)|1(?:29[2-5]|[346]92)))',
-    '442' => '(?:8(?:5(?:20|3[0-358]|0[1-35-79]|6[169]|1[0-35-8]|5[58]|7[35-7]|8[015-8]|9[01]|4[013-6])|60[1-3]))',
+    '442' => '(?:8(?:5(?:20|3[0-358]|0[1-35-79]|6[169]|5[058]|1[0-35-8]|7[35-7]|8[015-8]|9[01]|4[013-6])|60[1-3]))',
     '443' => '(?:(?:8(?:5(?:[05]5|88)|6[01]1)|019[2-4]))',
     '444' => '(?:(?:8(?:5(?:77|3[03]|0[1378]|6[047]|2[025]|1[0-25-7]|4[0235]|8[01568]|5[1-58])|6(?:86|0[126]|1[0-2])|7(?:10|87))|0(?:3(?:81|9[1-8])|49[2-6]|59[2356]|19[2-4]|798)|1(?:3(?:8[5-8]|9[3478])|19[2358]|29[5-8])|3(?:59[2-5]|69[2568])|2(?:19[238]|89[23])))',
     '445' => '(?:8(?:5(?:[58]5|1[01]|0[1-35])|60[12]))',
@@ -436,7 +436,7 @@ our %ZIP_TABLE = (
     '462' => '(?:8(?:5(?:2[23]|7[5-7]|5[158]|0[189]|3[05]|1[129]|8[08]|4[035])|666|739))',
     '463' => '(?:85(?:10|5[057]|2[128]|8[05]|6[0157]|7[157]|0[1-35]|3[03568]|4[013578]))',
     '464' => '(?:8(?:5(?:85|91|4[05-7]|5[058]|2[0-25]|1[12]|6[0167]|3[01369]|7[017])|6(?:[78]1|0[1-3]|4[134]|3[1-357]|6[12]|1[0135-8]|5[0-24])|710))',
-    '465' => '(?:8(?:5(?:20|6[05-7]|5[0-258]|0[15-8]|1[0156])|6(?:51|68|70|1[0-2]|2[026])))',
+    '465' => '(?:8(?:5(?:20|6[05-7]|5[0-258]|0[15-8]|1[0156])|6(?:68|70|1[0-2]|5[01]|2[026])))',
     '466' => '(?:8(?:5(?:40|6[05-7]|3[39]|2[25]|8[058]|1[0-25]|5[0458]|0[125-8])|6(?:10|73|88|6[06]|5[05-7]|3[0356])|7(?:11|0[17])))',
     '467' => '(?:8(?:5(?:01|6[1-367]|7[17]|3[013]|8[0158]|5[58]|2[0-2]|1[01])|6(?:51|86|2[26]|0[1-3]|3[39]|1[01])))',
     '468' => '(?:8(?:5(?:51|2[02]|0[1-357]|1[0-4]|8[58]|3[1-467])|626))',
@@ -470,7 +470,7 @@ our %ZIP_TABLE = (
     '497' => '(?:8(?:5(?:[04][158]|3[138]|2[27]|1[0-2])|60[12]))',
     '498' => '(?:850[1-35])',
     '500' => '(?:8(?:6(?:[14][0568]|5[057]|7[0-26-8]|2[0-25]|0[1-357]|8[0-25-79]|3[05-9]|6[06-8])|5(?:88|6[0-25-7]|0[1-578]|1[0358]|4[0145]|2[1-5]|3[035]|7[017]|5[024-8])|7(?:65|4[0-38]|2[1-357-9]|1[015-8]|3[0-479]|5[0-5]|0[1-378])))',
-    '501' => '(?:(?:0(?:49[2-8]|69[2-7]|29[2-6]|59[26]|79[78]|[13]92)|3(?:99[2-48]|29[356]|39[235]|89[2-4]|792)|6(?:1(?:9[2-8]|8[01])|29[235])|1(?:19[2-68]|39[23]|[25]92)|4(?:29[278]|19[23]|59[25])|2(?:[1258]92|69[578])|5(?:[146]92|393)))',
+    '501' => '(?:(?:0(?:49[2-8]|69[2-8]|29[2-6]|59[26]|79[78]|[13]92)|3(?:99[2-48]|29[356]|39[235]|89[2-4]|792)|6(?:1(?:9[2-8]|8[01])|29[235])|1(?:19[2-68]|39[23]|[25]92)|4(?:29[278]|19[23]|59[25])|2(?:[1258]92|69[578])|5(?:[146]92|393)))',
     '502' => '(?:8(?:5(?:[12]1|58|67|85|0[13])|792))',
     '503' => '(?:(?:8(?:5(?:5[02-46-9]|2[0-3]|[01][1-9]|7[01]|6[0-24-9])|60[134])|2(?:39[2-7]|49[2-5]|19[23])|0(?:19[258]|29[25]|[46]95|392)|1(?:39[2-6]|59[235]|696)))',
     '504' => '(?:8(?:5(?:[48]5|11|0[14]|5[15])|7(?:10|0[12])|6(?:01|42)))',
@@ -478,7 +478,7 @@ our %ZIP_TABLE = (
     '506' => '(?:(?:8(?:6(?:66|78|90|0[13]|8[6-8])|5(?:77|85|0[26]|5[05]))|1(?:49[23568]|19[56]|392)|019[24]|2192))',
     '507' => '(?:8(?:5(?:11|33|85|6[18]|2[237])|7(?:87|0[1-3568])|60[1-3578]))',
     '508' => '(?:(?:8(?:5(?:[58]5|11|0[0-2])|6(?:[68]6|11))|0(?:292|494)))',
-    '509' => '(?:(?:7(?:79[2357]|[258]92|49[23]|69[23])|0(?:29[2-8]|19[278]|393|492)|1(?:39[2-6]|19[23]|69[25]|492)|5(?:19[23568]|292|494)|9(?:29[23568]|19[235])|2(?:59[2358]|29[235])|(?:83|4[1-3])92|3(?:195|292)|619[2-6]))',
+    '509' => '(?:(?:0(?:2(?:89|9[2-8])|19[278]|393|492)|7(?:79[2357]|[258]92|49[23]|69[23])|1(?:39[2-6]|19[23]|69[25]|492)|5(?:19[23568]|292|494)|9(?:29[23568]|19[235])|2(?:59[2358]|29[235])|(?:83|4[1-3])92|3(?:195|292)|619[2-6]))',
     '510' => '(?:(?:8(?:5(?:[34]0|5[0257]|0[2-5]|8[058]|1[0-25]|7[57]|2[02568]|6[0-27])|6(?:[23]1|42|66|70|5[15]|1[56]|0[145]))|0(?:29[2-58]|[13]92)|1292))',
     '511' => '(?:(?:8(?:5(?:[67]7|02|33|5[058]|8[58]|1[01])|6(?:[68]6|01|78)|7(?:11|98))|0(?:29[2-68]|19[28]|49[28]|59[23])|1192))',
     '512' => '(?:85(?:12|38|50))',
@@ -509,8 +509,8 @@ our %ZIP_TABLE = (
     '537' => '(?:8(?:(?:50|91)1|686))',
     '538' => '(?:8(?:5(?:[58]5|01|10)|6(?:[68]6|55)))',
     '539' => '(?:8794)',
-    '540' => '(?:(?:8(?:5(?:6[06]|5[0-3589]|4[0147]|2[1267]|3[03-5]|0[1578]|7[01578]|8[157]|1[0-2579])|6(?:86|1[015]|4[25]|2[02]|3[09]|0[2-8]|7[078]|6[08])|795)|6255))',
-    '541' => '(?:(?:8(?:5(?:5[0136-9]|2[013-689]|1[135-8]|4[0-35-7]|7[2568]|8[1579]|0[1-35689]|6[0136-8]|3[014578])|765)|6666))',
+    '540' => '(?:(?:8(?:5(?:6[06]|5[0-3589]|4[0147]|2[1267]|8[15-7]|3[03-5]|0[1578]|7[01578]|1[0-2579])|6(?:86|1[015]|4[25]|2[02]|3[09]|0[2-8]|7[078]|6[08])|795)|6255))',
+    '541' => '(?:(?:8(?:5(?:5[0136-9]|2[013-689]|7[2568]|1[135-9]|4[0-357]|8[1579]|0[1-35689]|6[0136-8]|3[014578])|630|765)|6666))',
     '542' => '(?:8(?:5(?:33|42|77|0[1-4]|8[0568]|6[67]|2[235]|5[0458]|1[01])|6(?:54|60|8[68])|745))',
     '543' => '(?:8(?:5(?:[34]3|11|0[1-3]|[58][58])|6(?:01|66|8[68])))',
     '544' => '(?:8(?:5(?:[58]5|01)|6[68]6))',
@@ -529,7 +529,7 @@ our %ZIP_TABLE = (
     '558' => '(?:85(?:01|85|5[58]))',
     '559' => '(?:8(?:5(?:1[019]|5[03589]|8[58]|0[126]|6[01])|6(?:11|0[1245]|5[18])|729))',
     '560' => '(?:85(?:79|80|4[38]|5[0-25]|6[0157]|3[12]|0[56]))',
-    '561' => '(?:85(?:01|20|77|5[058]|1[01]))',
+    '561' => '(?:85(?:[23]0|01|77|5[058]|1[01]))',
     '562' => '(?:8(?:5(?:11|22|43|55|8[0568]|0[58]|6[0278])|6(?:78|86)))',
     '563' => '(?:(?:85(?:[67]7|10|88)|0[23]92))',
     '564' => '(?:8(?:5(?:23|5[015]|0[13]|6[57]|1[15])|6(?:80|5[01])))',
@@ -626,7 +626,7 @@ our %ZIP_TABLE = (
     '660' => '(?:85(?:01|33|67|4[04]|5[058]|1[01]|8[0258]))',
     '661' => '(?:8(?:5(?:[23]0|01|77|6[47]|5[058]|8[58]|1[01])|661))',
     '662' => '(?:85(?:[34]3|10|21|67|8[056]|5[258]|0[1-35]))',
-    '663' => '(?:8(?:5(?:[67]7|01|10|45|58|8[568])|601))',
+    '663' => '(?:8(?:5(?:[13]0|[67]7|01|45|58|8[568])|601))',
     '664' => '(?:8(?:5(?:[58]8|33|2[02]|4[05]|0[1-3578]|1[01])|6(?:24|41|50|1[015])))',
     '665' => '(?:8(?:5(?:01|43|67|5[058]|8[58])|665))',
     '666' => '(?:(?:0292|8501))',
@@ -659,7 +659,7 @@ our %ZIP_TABLE = (
     '696' => '(?:(?:0(?:19[2358]|393|692)|8510))',
     '697' => '(?:(?:8(?:5(?:01|85|1[12])|686|789)|0492))',
     '698' => '(?:(?:8(?:50[13-5]|65[01])|0292))',
-    '699' => '(?:(?:0(?:5(?:88|9[23])|19[235]|29[23]|49[26]|69[67]|792)|1(?:39[2-6]|29[23]|592|898)|4(?:29[28]|692)|5(?:292|695)|2598))',
+    '699' => '(?:(?:0(?:5(?:88|9[23])|19[23]|29[23]|49[26]|69[67]|792)|1(?:39[2-6]|29[23]|592|898)|4(?:29[28]|692)|5(?:292|695)|2598))',
     '700' => '(?:8(?:5(?:2[0-2568]|4[04-69]|7[0-2578]|8[014-69]|0[1-8]|3[0-589]|5[0-24-8]|6[0-27-9]|1[0-24-9])|6(?:6[06]|7[78]|2[01358]|1[014-8]|5[057]|8[016-9]|0[1-8]|4[05]|3[459])|7(?:18|61|94|0[17]|2[27]|3[1-48])))',
     '701' => '(?:(?:0(?:29[25-8]|19[2357]|39[38])|4(?:39[248]|29[23]|59[23])|1(?:19[25]|29[26])|2(?:292|595)|329[23]))',
     '702' => '(?:8(?:5(?:44|0[1-35-8]|1[0-25])|60[1-35-79]))',
@@ -689,7 +689,7 @@ our %ZIP_TABLE = (
     '727' => '(?:8501)',
     '728' => '(?:85(?:11|0[1-3]))',
     '729' => '(?:(?:3(?:19[238]|49[278]|592)|0(?:49[25]|292|393)|2(?:39[2-4]|292)|149[23]|4295|5792))',
-    '730' => '(?:8(?:5(?:8[0235-9]|4[0-58]|6[1-35-7]|1[013-58]|5[0-289]|0[1-47-9]|7[015-7]|3[0-35689]|2[0-378])|6(?:7[02578]|4[1-36]|1[0-29]|8[067]|6[126-8]|5[0-8]|3[01]|2[026]|0[135689])|7(?:[23]0|87|0[1267]|9[4-7])))',
+    '730' => '(?:8(?:5(?:4[0-58]|6[1-35-7]|8[0235-79]|1[013-58]|5[0-289]|0[1-47-9]|7[015-7]|3[0-35689]|2[0-378])|6(?:7[02578]|4[1-36]|1[0-29]|8[067]|6[126-8]|5[0-8]|3[01]|2[026]|0[135689])|7(?:[23]0|87|0[1267]|9[4-7])))',
     '731' => '(?:(?:0(?:19[2-8]|29[235]|59[235]|692)|3(?:19[2-68]|39[358]|595)|4(?:39[236-8]|29[2-4])|1(?:59[57]|795)|519[35-8]|219[58]))',
     '732' => '(?:8(?:5(?:55|80|6[4-6]|7[05]|1[0-2]|0[13-57-9])|652|765))',
     '733' => '(?:8(?:6(?:89|3[03]|4[1-36-8]|6[09]|7[0578]|0[18]|2[1-7]|5[01]|1[016])|5(?:0[19]|4[0358]|5[0-358]|2[0158]|3[0135]|1[0-4])|701))',
@@ -741,7 +741,7 @@ our %ZIP_TABLE = (
     '780' => '(?:8(?:5(?:3[024-69]|0[1-47-9]|4[0145]|5[03-589]|1[024-7]|2[0278]|6[125-8]|7[0-27])|6(?:86|7[067]|0[125]|6[0-3568])|787))',
     '781' => '(?:(?:9(?:5(?:[05]6|48|3[378]|2[569]|1[139])|68[3-9])|85(?:21|43|60|88|1[015]|5[1257])|5(?:19[25]|29[25]|79[23]|495)|(?:03|42|1[158])92|2(?:19[2-4]|492)|3(?:49[23]|692)|7185))',
     '782' => '(?:8502)',
-    '783' => '(?:85(?:[58]5|10|0[125-9]))',
+    '783' => '(?:85(?:[58]5|0[125-9]|1[01]))',
     '784' => '(?:850[135])',
     '785' => '(?:(?:8(?:5(?:[01]1|20|33|85|7[046-8])|601)|0[156]95))',
     '786' => '(?:(?:0393|8501))',
@@ -862,7 +862,7 @@ our %ZIP_TABLE = (
     '901' => '(?:(?:2(?:5(?:40|88|97|0[1267]|6[0679]|1[0-25]|5[0-35-9]|2[0156]|3[01])|6(?:86|0[127]|1[01])|7(?:01|10|33)|49[2356]|39[235])|0(?:19[2-467]|49[2-6]|29[245]|39[23]|592)|1(?:19[2356]|39[23]|49[25]|292|595)|3(?:[679]92|19[23]|59[25]|496|895)))',
     '902' => '(?:85(?:21|1[0-3]|8[58]|5[05]|7[01]))',
     '903' => '(?:(?:02(?:20|1[013-578]|0[13-7])|860[1-3]))',
-    '904' => '(?:(?:0(?:49[2-7]|39[2-58]|19[2-5]|29[35])|2(?:19[2-46]|39[2-4]|29[23])|8(?:5(?:[01]1|85)|686)|1(?:29[2-4]|[13]92)))',
+    '904' => '(?:(?:0(?:49[2-7]|39[2-58]|19[2-5]|29[35])|2(?:19[2-46]|29[2-4]|39[2-4])|8(?:5(?:[01]1|85)|686)|1(?:29[2-4]|[13]92)))',
     '905' => '(?:(?:0(?:59[2-6]|79[2-6]|[24]92|695)|8(?:5(?:01|12|40|85)|6(?:11|68))|1(?:[23]92|495)|2192))',
     '906' => '(?:(?:8(?:5(?:01|50)|601)|0[256]92))',
     '907' => '(?:(?:850[1-3]|1[28]92))',
@@ -896,7 +896,7 @@ our %ZIP_TABLE = (
     '937' => '(?:8(?:5(?:[58]5|03|11|6[67])|6(?:01|60|78)))',
     '938' => '(?:(?:8(?:6(?:1[0-3]|0[12])|5(?:[58]5|0[25]))|029[23]))',
     '939' => '(?:(?:8(?:5(?:21|67|0[127]|[58][058]|1[0157]|7[12])|6(?:01|50|3[06]|4[02]|1[01]))|1(?:39[2-8]|89[23578]|59[2356]|69[2-48]|19[23]|99[78]|492)|0(?:29[2-6]|79[2358]|39[258]|[15]92|693)|2(?:29[23578]|39[238]|69[24]|192|595|798)|3593))',
-    '940' => '(?:(?:8(?:5(?:32|67|7[027]|2[12]|0[18]|5[0458]|1[01]|8[03568])|6(?:41|60|86|3[013]|5[0134]|0[235]|[12][0-2])|707)|2(?:1(?:8[1-468]|9[258])|0(?:93|8[1-358])|392|595)|029[2-8]|119[3-68]))',
+    '940' => '(?:(?:8(?:5(?:67|7[027]|3[02]|2[12]|0[18]|5[0458]|1[01]|8[03568])|6(?:41|60|86|3[013]|5[0134]|0[235]|[12][0-2])|707)|2(?:1(?:8[1-468]|9[258])|0(?:93|8[1-358])|392|595)|029[2-8]|119[3-68]))',
     '941' => '(?:8(?:6(?:[01]1|86)|50[12]))',
     '942' => '(?:(?:8(?:5(?:63|0[1258])|6(?:[01]1|66))|0(?:19[2-6]|39[238]|492)|1492))',
     '943' => '(?:(?:8(?:5(?:61|1[025]|4[045]|3[0134]|2[0-25]|8[58]|5[125]|0[1-35])|6(?:1[06]|0[147]))|0(?:19[23]|595|692)))',
@@ -906,7 +906,7 @@ our %ZIP_TABLE = (
     '947' => '(?:(?:8(?:5(?:[58]5|40|0[1-46])|7(?:01|65))|019[238]))',
     '948' => '(?:(?:8(?:50[1-4]|602)|0192))',
     '949' => '(?:(?:7(?:49[24-6]|59[24]|277|392)|3(?:29[2-468]|19[2-4]|494)|6(?:69[256]|[124]92|797)|4(?:19[2-4]|39[278])|2(?:19[2-4]|39[24])|5(?:49[2-4]|292)|039[238]|8492))',
-    '950' => '(?:(?:8(?:5(?:6[05-7]|2[02-48]|3[0-3579]|0[1-57]|4[013-578]|1[0-48]|5[0-35-9]|7[0-25-79]|8[0-689])|6(?:7[78]|6[0168]|1[09]|5[0145]|0[1-3568]|[48][01]|2[0-69]|3[039])|7(?:0[7-9]|5[01359]|3[0235-8]|2[0-57]|1[015-8]|9[48]|4[0-24-9])|801)|1(?:1(?:79|9[2-7]|8[1-36-9])|29[2-68]|49[258])|2(?:0(?:8[24-9]|9[235-7])|1(?:8[18]|9[258])|292)|0(?:19[23568]|292)|3(?:19[578]|393)))',
+    '950' => '(?:(?:8(?:5(?:6[05-7]|3[0-3579]|0[1-57]|4[013-578]|1[0-48]|5[0-35-9]|7[0-25-79]|8[0-689]|2[02-4])|6(?:7[78]|6[0168]|1[09]|5[0145]|0[1-3568]|[48][01]|2[0-69]|3[039])|7(?:0[7-9]|5[01359]|3[0235-8]|2[0-57]|1[015-8]|9[48]|4[0-24-9])|801)|1(?:1(?:79|9[2-7]|8[1-36-9])|29[2-68]|49[258])|2(?:0(?:8[24-9]|9[235-7])|1(?:8[18]|9[258])|292)|0(?:19[23568]|292)|3(?:19[578]|393)))',
     '951' => '(?:8(?:5(?:70|4[04]|2[018]|1[0-489]|6[067]|3[01356]|8[0156]|0[2-478]|5[0-6])|6(?:01|40|78|8[056]|5[05]|3[023]|2[029]|1[0-2]|6[68])))',
     '952' => '(?:(?:1(?:59[23]|292|393)|850[12]))',
     '953' => '(?:(?:8(?:6(?:66|0[12])|50[13])|019[23]))',
